@@ -10,8 +10,6 @@ use Time::HiRes qw(usleep);
 
 use lib 't/lib';
 use forker;
-use OtherThing;
-use test::TestThing;
 
 # -----------------------------------------------------
 #               RecordStore
